# 作者寄语

## ==史云龙==

- 很多项目存在的问题是，直接就给用户使用了，用户完全没有适应过程，所以我提出了`Free Coding`的理念，就是自由编码。
- 程序运行起来后，所有的代码都应该是热更新的，而不是一个地方出错，整个程序罢工
- 项目开启后的文档管理也是非常混乱，并且都不能做到即时更新，项目的0-1，就应该是整体所有参与者和使用者一同使用

---

## 为什么要做**Bomiot**

- 开源软件就应该是个工具类的东西，很多开源软件做着做着，做成了应用软件
- 这样使得用户的学习成本非常高，而且不方便维护
- 只要做好底层工具，能够更便捷的得到用户想要的功能就可以了
- 通过工具，可以有效地拓展更多功能，这才是我认为开源软件应该做的

---

## 性能

- **Bomiot** 的底层ASGI是用**Rust**写的，所以保证了一定的性能
- 可以使用**locust**对自己的项目进行性能测试
- 原生也提供了3个测试接口，FastAPI是最快的，Django是最慢的

---

## 信号

- **Bomiot** 的信号机制，所有文档和数据都是实时交流的
- 不需要刷新服务器，就可以自由编码
- **Bomiot** 创造的是一个更友好，自由，便捷的开发和部署环境
